@@ -126,8 +126,8 @@ class Purchase(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMi
         self.Credit = False
         self.TotalAmt = 0
         self.PrintStatus = "NeedToPrint"
-        self.PurchaseEx = ""
-        self.TxnSource = ""
+        self.PurchaseEx = None
+        self.TxnSource = None
         self.GlobalTaxCalculation = "TaxExcluded"
 
         self.TxnTaxDetail = None
