@@ -1,5 +1,6 @@
 import unittest
 
+from quickbooks import QuickBooks
 from quickbooks.objects.purchase import Purchase, PurchaseLine, AccountBasedExpenseLineDetail, \
     ItemBasedExpenseLineDetail
 
@@ -27,6 +28,13 @@ class PurchaseTests(unittest.TestCase):
 
         self.assertEquals(str(purchase), "1000")
 
+    def test_valid_object_name(self):
+        obj = Purchase()
+        client = QuickBooks()
+        result = client.isvalid_object_name(obj.qbo_object_name)
+
+        self.assertTrue(result)
+
 
 class ItemBasedExpenseLineDetailTest(unittest.TestCase):
     def test_init(self):
