@@ -1,5 +1,6 @@
 import unittest
 
+from quickbooks import QuickBooks
 from quickbooks.objects.purchaseorder import PurchaseOrderLine, PurchaseOrder, ItemBasedExpenseLineDetail
 
 
@@ -18,6 +19,13 @@ class PurchaseOrderTests(unittest.TestCase):
 
         self.assertEquals(str(purchase_order), '1000')
 
+    def test_valid_object_name(self):
+        obj = PurchaseOrder()
+        client = QuickBooks()
+        result = client.isvalid_object_name(obj.qbo_object_name)
+
+        self.assertTrue(result)
+
 
 class ItemBasedExpenseLineDetailTests(unittest.TestCase):
     def test_init(self):
