@@ -1,5 +1,6 @@
 import unittest
 
+from quickbooks import QuickBooks
 from quickbooks.objects.taxcode import TaxCode, TaxRateDetail, TaxRateList
 
 
@@ -10,6 +11,13 @@ class TaxCodeTests(unittest.TestCase):
 
         self.assertEquals(str(taxcode), "test")
 
+    def test_valid_object_name(self):
+        obj = TaxCode()
+        client = QuickBooks()
+        result = client.isvalid_object_name(obj.qbo_object_name)
+
+        self.assertTrue(result)
+
 
 class TaxRateDetailTests(unittest.TestCase):
     def test_init(self):
